Title: [167756] trunk/Source/WebInspectorUI
Revision
167756
Author
grao...@webkit.org
Date
2014-04-24 07:37:15 -0700 (Thu, 24 Apr 2014)

Log Message

Web Inspector: gradient editor does not appear for linear-gradient with no specified angle
https://bugs.webkit.org/show_bug.cgi?id=132083

Reviewed by Timothy Hatcher.

Only assume we're parsing a legacy-formatted gradient if the first parameter is not a color.

* UserInterface/Models/Gradient.js:
(WebInspector.LinearGradient.linearGradientWithComponents):

Modified Paths

Diff

Modified: trunk/Source/WebInspectorUI/ChangeLog (167755 => 167756)


--- trunk/Source/WebInspectorUI/ChangeLog	2014-04-24 14:27:54 UTC (rev 167755)
+++ trunk/Source/WebInspectorUI/ChangeLog	2014-04-24 14:37:15 UTC (rev 167756)
@@ -1,3 +1,15 @@
+2014-04-24  Antoine Quint  <grao...@webkit.org>
+
+        Web Inspector: gradient editor does not appear for linear-gradient with no specified angle
+        https://bugs.webkit.org/show_bug.cgi?id=132083
+
+        Reviewed by Timothy Hatcher.
+
+        Only assume we're parsing a legacy-formatted gradient if the first parameter is not a color.
+
+        * UserInterface/Models/Gradient.js:
+        (WebInspector.LinearGradient.linearGradientWithComponents):
+
 2014-04-22  Brent Fulgham  <bfulg...@apple.com>
 
         [Win] Support Python 2.7 in Cygwin

Modified: trunk/Source/WebInspectorUI/UserInterface/Models/Gradient.js (167755 => 167756)


--- trunk/Source/WebInspectorUI/UserInterface/Models/Gradient.js	2014-04-24 14:27:54 UTC (rev 167755)
+++ trunk/Source/WebInspectorUI/UserInterface/Models/Gradient.js	2014-04-24 14:37:15 UTC (rev 167756)
@@ -188,8 +188,9 @@
             return null;
         }
         components.shift();
-    } else {
-        // We don't support any of the legacy linear gradient formats.
+    } else if (components[0].length !== 1 && !WebInspector.Color.fromString(components[0][0])) {
+        // If the first component is not a color, then we're dealing with a
+        // legacy linear gradient format that we don't support.
         return null;
     }
 
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to